# PyHdust filters

- ESO SkyCalc filters ("Johnson", from U to Q, uppercase, no instrument ID)
- filter_instrument (otherwise)

Wavelength in Angstroms!

# Zero point levels

Band | Photometric zeropoint in ergs/s/cm2/A (flux for zero mag in Vega system)
--- | ---
U | U0 = 4.18023e-09
B | B0 = 6.60085e-09
V | V0 = 3.60994e-09
R | R0 = 2.28665e-09
I | I0 = 1.22603e-09
Z | Z0 = 7.76068e-10
Y | Y0 = 5.973e-10
J | J0 = 3.12e-10
H | H0 = 1.14e-10
K | K0 = 3.94e-11
L | L0 = 4.83e-12
M | M0 = 2.04e-12
N | N0 = 1.23e-13
Q | Q0 = 6.8e-15
Paranal_VISIR.J122 | Paranal_VISIR.J122_0 = 5.782e-14

# Sources

SVO Filter Profile Service - filter standardization in the VO
  http://svo2.cab.inta-csic.es/svo/theory/fps3/index.php?mode=browse
SkyCalc - ESO Sky Model Calculator (contains Photometric zeropoint in ergs/s/cm2/A)
  https://www.eso.org/observing/etc/doc/skycalc/helpskycalc.html
ESO FORS filters (not in SVO)
  http://www.eso.org/sci/facilities/paranal/instruments/fors/inst/Filters/curves.html
Wikipedia - Photometric system article
  https://en.wikipedia.org/wiki/Photometric_system
NIRC2 Keck (not in SVO; no curves, only info)
  http://www2.keck.hawaii.edu/inst/nirc2/filters.html
Other filters lists

  http://www.astro.caltech.edu/~capak/filters/index.html

  http://www.aip.de/en/research/facilities/stella/instruments/data

  http://www.mso.anu.edu.au/~brad/filters.html

AstroSurf - comercial filters response
  http://www.astrosurf.com/buil/filters/curves.htm